ghettoq Documentation
==================================

Contents:

.. toctree::
    :maxdepth: 3

    introduction
    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

